==> zio-aws-gamelift_2.12-5.19.7.5-sources.jar: zio/aws/gamelift/model/MatchedPlayerSession.scala <==
package zio.aws.gamelift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.gamelift.model.primitives.{PlayerSessionId, NonZeroAndMaxString}
import scala.jdk.CollectionConverters._
final case class MatchedPlayerSession(
    playerId: Optional[NonZeroAndMaxString] = Optional.Absent,
    playerSessionId: Optional[PlayerSessionId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession = {
    import MatchedPlayerSession.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
      .builder()
      .optionallyWith(
        playerId.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.playerId)
      .optionallyWith(
        playerSessionId.map(value =>
          PlayerSessionId.unwrap(value): java.lang.String
        )
      )(_.playerSessionId)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly =
    zio.aws.gamelift.model.MatchedPlayerSession.wrap(buildAwsValue())
}
object MatchedPlayerSession {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.MatchedPlayerSession =
      zio.aws.gamelift.model.MatchedPlayerSession(
        playerId.map(value => value),
        playerSessionId.map(value => value)
      )
    def playerId: Optional[NonZeroAndMaxString]
    def playerSessionId: Optional[PlayerSessionId]
    def getPlayerId: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("playerId", playerId)
    def getPlayerSessionId: ZIO[Any, AwsError, PlayerSessionId] =
      AwsError.unwrapOptionField("playerSessionId", playerSessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ) extends zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly {
    override val playerId: Optional[NonZeroAndMaxString] = zio.aws.core.internal
      .optionalFromNullable(impl.playerId())
      .map(value =>
        zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
      )
    override val playerSessionId: Optional[PlayerSessionId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.playerSessionId())
        .map(value => zio.aws.gamelift.model.primitives.PlayerSessionId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ): zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly = new Wrapper(impl)
}

==> zio-aws-gamelift_2.13-5.17.116.2-sources.jar: zio/aws/gamelift/model/MatchedPlayerSession.scala <==
package zio.aws.gamelift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.gamelift.model.primitives.{PlayerSessionId, NonZeroAndMaxString}
import scala.jdk.CollectionConverters._
final case class MatchedPlayerSession(
    playerId: Option[NonZeroAndMaxString] = None,
    playerSessionId: Option[PlayerSessionId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession = {
    import MatchedPlayerSession.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
      .builder()
      .optionallyWith(
        playerId.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.playerId)
      .optionallyWith(
        playerSessionId.map(value =>
          PlayerSessionId.unwrap(value): java.lang.String
        )
      )(_.playerSessionId)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly =
    zio.aws.gamelift.model.MatchedPlayerSession.wrap(buildAwsValue())
}
object MatchedPlayerSession {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.MatchedPlayerSession =
      zio.aws.gamelift.model.MatchedPlayerSession(
        playerId.map(value => value),
        playerSessionId.map(value => value)
      )
    def playerId: Option[NonZeroAndMaxString]
    def playerSessionId: Option[PlayerSessionId]
    def getPlayerId: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("playerId", playerId)
    def getPlayerSessionId: ZIO[Any, AwsError, PlayerSessionId] =
      AwsError.unwrapOptionField("playerSessionId", playerSessionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ) extends zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly {
    override val playerId: Option[NonZeroAndMaxString] = scala
      .Option(impl.playerId())
      .map(value =>
        zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
      )
    override val playerSessionId: Option[PlayerSessionId] = scala
      .Option(impl.playerSessionId())
      .map(value => zio.aws.gamelift.model.primitives.PlayerSessionId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.MatchedPlayerSession
  ): zio.aws.gamelift.model.MatchedPlayerSession.ReadOnly = new Wrapper(impl)
}
